@@ -2,7 +2,7 @@ package Test2::Compare::Delta;
 use strict;
 use warnings;
 
-our $VERSION = '0.000039';
+our $VERSION = '0.000040';
 
 use Test2::Util::HashBase qw{verified id got chk children dne exception};
 
@@ -292,12 +292,12 @@ sub table {
 
     my @no_collapse = grep { $COLUMNS{$COLUMN_ORDER[$_]}->{no_collapse} } 0 .. $#COLUMN_ORDER;
     unshift @out => Test2::Util::Table::table(
-        header      => $header,
-        rows        => $rows,
+        header      => [@$header],
+        rows        => [@$rows],
         collapse    => 1,
         sanitize    => 1,
         mark_tail   => 1,
-        no_collapse => \@no_collapse,
+        no_collapse => [@no_collapse],
     );
 
     return @out;
